package ca.datasports.sb.utilities;

import com.streambase.sb.Schema;
import com.streambase.sb.operator.TypecheckException;

/**
 * Helper class that encapsulates a function to verify that all expected fields are present
 * in a given schema, and that they have the correct type.
 *  
 * @author Phil Martin, <a href="mailto:phil.martin@datasports.ca">phil.martin@datasports.ca</a>.
 *
 */
public class SchemaValidator {
	/**
	 * Helper function to verify that all expected fields are present in a given schema, 
	 * and that they have the correct type.
	 * 
	 * @param testSchema the schema to examine.
	 * @param referenceSchema the schema that contains the required fields to be used as a reference. 
	 * @throws TypecheckException
	 */
	public static void validateSchema(Schema testSchema, Schema referenceSchema) throws TypecheckException {
		for (Schema.Field curField : referenceSchema.fields()) {
			try {
				Schema.Field testField = testSchema.getField(curField.getName());
				
				if (testField.getDataType() != curField.getDataType())
				{
					throw new TypecheckException("Field '"
						+ curField.getName() + "' has wrong type.  Should be "
						+ curField.getDataType().getName() + ", but is "
						+ testField.getDataType().getName() + ".");
				}
			}
			catch (Exception exc) {
				throw new TypecheckException("Schema is missing required field '" 
						+ curField.getName() + "', type " 
						+ curField.getDataType().getName());
			}
		}
	}
}
